@@ -55,3 +55,20 @@ pub fn marine_test(attrs: TokenStream, input: TokenStream) -> TokenStream {
         Err(e) => proc_macro_error::abort!(attrs_span, format!("{}", e)),
     }
 }
+
+// deprecated macro for backwards compatibility
+#[deprecated(since = "0.6.2", note = "please use the #[marine] macro instead")]
+#[proc_macro_error]
+#[proc_macro_attribute]
+pub fn fce_test(attrs: TokenStream, input: TokenStream) -> TokenStream {
+    let attrs: proc_macro2::TokenStream = attrs.into();
+    let attrs_span = attrs.span();
+    // here it obtains a path to the current file where macro is applied
+    let mut file_path = proc_macro::Span::call_site().source_file().path();
+    let _ = file_path.pop();
+
+    match marine_test_impl(attrs, input.into(), file_path) {
+        Ok(stream) => stream.into(),
+        Err(e) => proc_macro_error::abort!(attrs_span, format!("{}", e)),
+    }
+}
